import React, { Component, ComponentType, CSSProperties, RefObject } from "react";
import { BoundingRect, Coords, NormalizedAreaSelection, NormalizedPosition, SelectionType } from "../types";
import { AreaSelectionProps } from "./AreaSelection";
import { NewAreaSelectionProps } from "./NewAreaSelection";
import { TextSelectionProps } from "./TextSelection";
export interface PdfPageProps {
    pageNumber: number;
    style: CSSProperties;
    innerRef: RefObject<HTMLDivElement>;
    areaSelectionActive: boolean;
    pageDimensions?: {
        width: number;
        height: number;
    };
    selections?: SelectionType[];
    enableAreaSelection?: (event: React.MouseEvent) => boolean;
    onAreaSelectionStart?: (pageNumber: number) => void;
    onAreaSelectionEnd?: (selection: NormalizedAreaSelection) => void;
    textSelectionComponent?: ComponentType<TextSelectionProps>;
    areaSelectionComponent?: ComponentType<AreaSelectionProps>;
    newAreaSelectionComponent?: ComponentType<NewAreaSelectionProps>;
}
interface PdfPageState {
    renderComplete: boolean;
    areaSelection?: {
        originTarget?: HTMLElement;
        start?: Coords;
        position?: NormalizedPosition;
        locked?: boolean;
    };
}
export declare class PdfPage extends Component<PdfPageProps, PdfPageState> {
    state: PdfPageState;
    inputRef: React.RefObject<HTMLDivElement>;
    _mounted: boolean;
    componentDidMount: () => void;
    componentWillUnmount: () => void;
    shouldComponentUpdate(nextProps: Readonly<PdfPageProps>, nextState: Readonly<PdfPageState>): boolean;
    containerCoords: (pageX: number, pageY: number) => {
        x: number;
        y: number;
    } | undefined;
    getBoundingRect(start: Coords, end: Coords, clip?: BoundingRect): BoundingRect;
    onAreaSelectStart: (event: React.MouseEvent) => void;
    getAreaSelectionPosition: (event: MouseEvent) => NormalizedPosition | undefined;
    onAreaSelectChange: (event: MouseEvent) => void;
    onAreaSelectEnd: (event: MouseEvent) => void;
    onPageLoad: () => void;
    onPageRender: () => void;
    onMouseDown: (event: React.PointerEvent<HTMLDivElement>) => void;
    onMouseMove: (event: MouseEvent) => void;
    onMouseUp: (event: MouseEvent) => void;
    renderSelections: () => JSX.Element | null;
    render: () => JSX.Element;
}
export {};
