import React, { Component, ComponentType, CSSProperties, ReactElement, RefObject } from "react";
import { pdfjs } from "react-pdf";
import "react-pdf/dist/esm/Page/AnnotationLayer.css";
import "../style/react_pdf_viewer.css";
import { NormalizedAreaSelection, NormalizedTextSelection, SelectionType } from "../types";
import { AreaSelectionProps } from "./AreaSelection";
import { NewAreaSelectionProps } from "./NewAreaSelection";
import { TextSelectionProps } from "./TextSelection";
export declare type PageDimensions = Map<number, {
    width: number;
    height: number;
}>;
interface PdfViewerProps {
    children?: (props: {
        document: ReactElement;
    }) => ReactElement;
    loading?: string | ReactElement | (() => ReactElement);
    url: string;
    selections?: Array<SelectionType>;
    scale: number;
    overscanCount: number;
    enableAreaSelection?: (event: React.MouseEvent) => boolean;
    onPageDimensions?: ({ pageDimensions, pageYOffsets, }: {
        pageDimensions: PageDimensions;
        pageYOffsets: number[];
    }) => void;
    onTextSelection?: (highlightTip?: NormalizedTextSelection) => void;
    onAreaSelection?: (highlightTip?: NormalizedAreaSelection) => void;
    textSelectionColor?: CSSProperties["color"];
    textSelectionComponent?: ComponentType<TextSelectionProps>;
    areaSelectionComponent?: ComponentType<AreaSelectionProps>;
    newAreaSelectionComponent?: ComponentType<NewAreaSelectionProps>;
}
interface PdfViewerState {
    documentUuid?: string;
    textSelectionEnabled: boolean;
    areaSelectionActivePage?: number;
    numPages: number;
    originalPageDimensions?: PageDimensions;
    pageDimensions?: PageDimensions;
    pageYOffsets?: number[];
    visiblePages?: number[];
}
export declare class PdfViewer extends Component<PdfViewerProps, PdfViewerState> {
    static defaultProps: {
        overscanCount: number;
        scale: number;
    };
    state: PdfViewerState;
    /** Total left and right border width, needed as offset to avoid PageCanvas rendering past right page border. */
    BORDER_WIDTH_OFFSET: number;
    TOP_WIDTH_OFFSET: number;
    containerDiv: HTMLElement | null;
    pageRefs: Map<number, RefObject<HTMLDivElement>>;
    selectionMap: Map<number, SelectionType[]> | undefined;
    _mounted: boolean;
    /**
     * Lifecycle function
     */
    componentDidMount: () => void;
    componentDidUpdate: (prevProps: PdfViewerProps) => void;
    componentWillUnmount: () => void;
    shouldComponentUpdate: (nextProps: Readonly<PdfViewerProps>, nextState: Readonly<PdfViewerState>) => boolean;
    /**
     * Helpers
     */
    resetSelections: () => void;
    computeSelectionMap: () => void;
    computePageDimensions: (pdf: pdfjs.PDFDocumentProxy) => void;
    computeScaledPageDimensions: (originalPageDimensions: PageDimensions) => void;
    getVisiblePages: (scrollElement: HTMLElement, pageYOffsets?: number[] | undefined) => number[];
    getItemKey: (index: number) => string;
    getPageRef: (pageNumber: number) => React.RefObject<HTMLDivElement>;
    /**
     * Text selection handlers
     */
    clearTextSelection: () => void;
    onTextSelectionStart: () => void;
    onTextSelectionChange: () => void;
    /**
     * Area selection handlers
     */
    clearAreaSelection: () => void;
    onAreaSelectionStart: (pageNumber: number) => void;
    onAreaSelectionEnd: (selection: NormalizedAreaSelection) => void;
    /**
     * Event handlers
     */
    onKeyDown: (event: KeyboardEvent) => void;
    onMouseDown: () => void;
    onScroll: (event: Event) => void;
    onDocumentLoad: (pdf: pdfjs.PDFDocumentProxy) => void;
    renderPages: () => JSX.Element[];
    render: () => React.ReactElement<any, string | ((props: any) => React.ReactElement<any, string | any | (new (props: any) => React.Component<any, any, any>)> | null) | (new (props: any) => React.Component<any, any, any>)>;
}
export {};
